@@ -364,9 +364,10 @@ typedef enum
 /**
  * pango_default_break:
  * @text: text to break
- * @length: length of text in bytes
- * @analysis: a #PangoAnalysis for the text
+ * @length: length of text in bytes (may be -1 if @text is nul-terminated)
+ * @analysis: a #PangoAnalysis for the @text
  * @attrs: logical attributes to fill in
+ * @attrs_len: size of the array passed as @attrs
  *
  * This is the default break algorithm, used if no language
  * engine overrides it. Normally you should use pango_break()
@@ -381,9 +382,12 @@ void
 pango_default_break (const gchar   *text,
                      gint           length,
                      PangoAnalysis *analysis,
-                     PangoLogAttr  *attrs)
-{  
-  /* The rationale for all this is in section 5.15 of the Unicode 3.0 book */
+                     PangoLogAttr  *attrs,
+                     int            attrs_len)
+{
+  /* The rationale for all this is in section 5.15 of the Unicode 3.0 book,
+   * the line breaking stuff is also in TR14 on unicode.org
+   */
 
   /* This is a default break implementation that should work for nearly all
    * languages. Language engines can override it optionally.
@@ -393,8 +397,8 @@ pango_default_break (const gchar   *text,
    * before we start, and then never assign FALSE to anything
    */
 
-  const gchar *next = text;
-  const gchar *end = text + length;
+  const gchar *next;
+  const gchar *end;
   gint i = 0;
   gunichar prev_wc;
   gunichar next_wc;
@@ -413,6 +417,12 @@ pango_default_break (const gchar   *text,
 
   g_return_if_fail (text != NULL);
   g_return_if_fail (attrs != NULL);
+
+  if (length < 0)
+    length = strlen (text);
+  
+  next = text;
+  end = text + length;
   
   if (next == end)
     return;
@@ -433,12 +443,28 @@ pango_default_break (const gchar   *text,
       GUnicodeBreakType break_type;
       BreakOpportunity break_op;
 
+      /* >, not >=, because of the extra newline we stick on the end */
+      if (i > attrs_len)
+        {
+          g_warning ("pango_default_break(): the array of PangoLogAttr passed in must have at least N+1 elements, if there are N characters in the text being broken");
+          return;
+        }
+      
       wc = next_wc;
 
       next = g_utf8_next_char (next);
 
-      if (next >= end)
-        next_wc = 0;
+      if (next == end)
+        {
+          /* This is how we fill in the last element (end position) of the
+           * attr array - assume there's a newline off the end of @text.
+           */
+          next_wc = '\n';
+        }
+      else if (next > end)
+        {
+          next_wc = 0;
+        }
       else
         {
           next_wc = g_utf8_get_char (next);
@@ -825,7 +851,7 @@ pango_default_break (const gchar   *text,
         }
 
       /* ---- Sentence breaks ---- */
-
+      
       /* The Unicode spec specifies sentence breakpoints, so that a piece of
        * text would be partitioned into sentences, and all characters would
        * be inside some sentence. This code implements that for is_sentence_boundary,
@@ -839,13 +865,30 @@ pango_default_break (const gchar   *text,
        * so am allowing one to be tacked onto a sentence ending in period.
        */
 
+#define MAYBE_START_NEW_SENTENCE                                \
+              switch (type)                                     \
+                {                                               \
+                case G_UNICODE_LINE_SEPARATOR:                  \
+                case G_UNICODE_PARAGRAPH_SEPARATOR:             \
+                case G_UNICODE_CONTROL:                         \
+                case G_UNICODE_FORMAT:                          \
+                case G_UNICODE_SPACE_SEPARATOR:                 \
+                  sentence_state = STATE_SENTENCE_OUTSIDE;      \
+                  break;                                        \
+                                                                \
+                default:                                        \
+                  sentence_state = STATE_SENTENCE_BODY;         \
+                  attrs[i].is_sentence_start = TRUE;            \
+                  break;                                        \
+                }
+      
       /* No sentence break at the start of the text */
 
       /* default to not a sentence breakpoint */
       attrs[i].is_sentence_boundary = FALSE;
       attrs[i].is_sentence_start = FALSE;
       attrs[i].is_sentence_end = FALSE;
-
+      
       /* FIXME the Unicode spec lumps control/format chars with
        * line/para separators in descriptive text, but not in the
        * character class specs, in table 5-6, so who knows whether you
@@ -922,7 +965,8 @@ pango_default_break (const gchar   *text,
           if (attrs[i].is_sentence_boundary)
             {
               attrs[i].is_sentence_end = TRUE;
-              sentence_state = STATE_SENTENCE_OUTSIDE;
+
+              MAYBE_START_NEW_SENTENCE;
             }
           else
             {
@@ -952,7 +996,8 @@ pango_default_break (const gchar   *text,
                 {
                   attrs[i].is_sentence_end = TRUE;
                   attrs[i].is_sentence_boundary = TRUE;
-                  sentence_state = STATE_SENTENCE_OUTSIDE;
+
+                  MAYBE_START_NEW_SENTENCE;
                 }
               break;
 
@@ -970,7 +1015,9 @@ pango_default_break (const gchar   *text,
             default:
               attrs[i].is_sentence_end = TRUE;
               attrs[i].is_sentence_boundary = TRUE;
-              sentence_state = STATE_SENTENCE_OUTSIDE;
+
+              MAYBE_START_NEW_SENTENCE;
+
               break;
             }
           break;
@@ -994,7 +1041,8 @@ pango_default_break (const gchar   *text,
                 {
                   attrs[i].is_sentence_end = TRUE;
                   attrs[i].is_sentence_boundary = TRUE;
-                  sentence_state = STATE_SENTENCE_OUTSIDE;
+
+                  MAYBE_START_NEW_SENTENCE;
                 }
               break;
 
@@ -1019,7 +1067,9 @@ pango_default_break (const gchar   *text,
             default:
               attrs[i].is_sentence_end = TRUE;
               attrs[i].is_sentence_boundary = TRUE;
-              sentence_state = STATE_SENTENCE_OUTSIDE;
+
+              MAYBE_START_NEW_SENTENCE;
+
               break;
             }
           break;
@@ -1048,7 +1098,9 @@ pango_default_break (const gchar   *text,
 
             default:
               attrs[i].is_sentence_boundary = TRUE;
-              sentence_state = STATE_SENTENCE_OUTSIDE;
+
+              MAYBE_START_NEW_SENTENCE;
+
               break;
             }
           break;
@@ -1061,7 +1113,9 @@ pango_default_break (const gchar   *text,
            */
           if (!(prev_wc == '\r' && wc == '\n'))
             attrs[i].is_sentence_boundary = TRUE;
-          sentence_state = STATE_SENTENCE_OUTSIDE;
+
+          MAYBE_START_NEW_SENTENCE;
+
           break;
 
         case STATE_SENTENCE_DOT:
@@ -1085,7 +1139,7 @@ pango_default_break (const gchar   *text,
                 {
                   attrs[i].is_sentence_end = TRUE;
 
-                  sentence_state = STATE_SENTENCE_OUTSIDE;
+                  MAYBE_START_NEW_SENTENCE;
                 }
               else
                 sentence_state = STATE_SENTENCE_BODY;
@@ -1110,7 +1164,7 @@ pango_default_break (const gchar   *text,
                 {
                   attrs[i].is_sentence_end = TRUE;
 
-                  sentence_state = STATE_SENTENCE_OUTSIDE;
+                  MAYBE_START_NEW_SENTENCE;
                 }
               else
                 sentence_state = STATE_SENTENCE_BODY;
@@ -1151,21 +1205,8 @@ pango_default_break (const gchar   *text,
               possible_sentence_end = -1;
               possible_sentence_boundary = -1;
 
-              switch (type)
-                {
-                case G_UNICODE_LINE_SEPARATOR:
-                case G_UNICODE_PARAGRAPH_SEPARATOR:
-                case G_UNICODE_CONTROL:
-                case G_UNICODE_FORMAT:
-                  sentence_state = STATE_SENTENCE_OUTSIDE;
-                  break;
-
-                default:
-                  g_assert (type != G_UNICODE_SPACE_SEPARATOR);
-                  sentence_state = STATE_SENTENCE_BODY;
-                  attrs[i].is_sentence_start = TRUE;
-                  break;
-                }
+              MAYBE_START_NEW_SENTENCE;
+              
               break;
             }
           break;
@@ -1196,21 +1237,8 @@ pango_default_break (const gchar   *text,
               possible_sentence_end = -1;
               possible_sentence_boundary = -1;
 
-              switch (type)
-                {
-                case G_UNICODE_LINE_SEPARATOR:
-                case G_UNICODE_PARAGRAPH_SEPARATOR:
-                case G_UNICODE_CONTROL:
-                case G_UNICODE_FORMAT:
-                  sentence_state = STATE_SENTENCE_OUTSIDE;
-                  break;
+              MAYBE_START_NEW_SENTENCE;
 
-                default:
-                  g_assert (type != G_UNICODE_SPACE_SEPARATOR);
-                  sentence_state = STATE_SENTENCE_BODY;
-                  attrs[i].is_sentence_start = TRUE;
-                  break;
-                }
               break;
             }
           break;
@@ -1223,7 +1251,6 @@ pango_default_break (const gchar   *text,
            */
           if (!(prev_wc == '\r' && wc == '\n'))
             attrs[i].is_sentence_boundary = TRUE;
-          sentence_state = STATE_SENTENCE_OUTSIDE;
 
           g_assert (possible_sentence_end >= 0);
           g_assert (possible_sentence_boundary >= 0);
@@ -1232,6 +1259,9 @@ pango_default_break (const gchar   *text,
 
           possible_sentence_end = -1;
           possible_sentence_boundary = -1;
+
+          MAYBE_START_NEW_SENTENCE;
+
           break;
 
         default:
@@ -1248,9 +1278,10 @@ pango_default_break (const gchar   *text,
 /**
  * pango_break:
  * @text:      the text to process
- * @length:    the length (in bytes) of @text
- * @analysis:  #PangoAnalysis structure from PangoItemize
+ * @length:    length of @text in bytes (may be -1 if @text is nul-terminated)
+ * @analysis:  #PangoAnalysis structure from pango_itemize()
  * @attrs:     an array to store character information in
+ * @attrs_len: size of the array passed as @attrs
  *
  * Determines possible line, word, and character breaks
  * for a string of Unicode text.
@@ -1259,7 +1290,8 @@ void
 pango_break (const gchar   *text,
              gint           length,
              PangoAnalysis *analysis,
-             PangoLogAttr  *attrs)
+             PangoLogAttr  *attrs,
+             int            attrs_len)
 {
   g_return_if_fail (text != NULL);
   g_return_if_fail (analysis != NULL);
@@ -1270,9 +1302,9 @@ pango_break (const gchar   *text,
 
   if (analysis->lang_engine &&
       analysis->lang_engine->script_break)
-    (* analysis->lang_engine->script_break) (text, length, analysis, attrs);
+    (* analysis->lang_engine->script_break) (text, length, analysis, attrs, attrs_len);
   else
-    pango_default_break (text, length, analysis, attrs);
+    pango_default_break (text, length, analysis, attrs, attrs_len);
 }
 
 /**
@@ -1287,7 +1319,7 @@ pango_break (const gchar   *text,
  * return-newline pair, or Unicode paragraph separator character.  The
  * index of the run of delimiters is returned in
  * @paragraph_delimiter_index. The index of the start of the paragraph
- * (index after all delimiters) is stored in @paragraph_start.
+ * (index after all delimiters) is stored in @next_paragraph_start.
  *
  * If no delimiters are found, both @paragraph_delimiter_index and
  * @next_paragraph_start are filled with the length of @text (an index one
@@ -1377,16 +1409,24 @@ pango_find_paragraph_boundary (const gchar *text,
  * @length: length in bytes of @text
  * @level: embedding level, or -1 if unknown
  * @language: language tag
- * @log_attrs: array with one PangoLogAttr per character in @text, to be filled in
+ * @log_attrs: array with one #PangoLogAttr per character in @text, plus one extra, to be filled in
+ * @attrs_len: length of @log_attrs array
  *
- * Computes a PangoLogAttr for each character in @text
+ * Computes a #PangoLogAttr for each character in @text. The @log_attrs
+ * array must have one #PangoLogAttr for each position in @text; if
+ * @text contains N characters, it has N+1 positions, including the
+ * last position at the end of the text. @text should be an entire
+ * paragraph; logical attributes can't be computed without context
+ * (for example you need to see spaces on either side of a word to know the
+ * word is a word).
  */
 void
 pango_get_log_attrs (const char    *text,
                      int            length,
                      int            level,
                      PangoLanguage *language,
-                     PangoLogAttr  *log_attrs)
+                     PangoLogAttr  *log_attrs,
+                     int            attrs_len)
 {
   int n_chars;
   PangoMap *lang_map;
@@ -1419,6 +1459,12 @@ pango_get_log_attrs (const char    *text,
 
   n_chars = g_utf8_strlen (text, length);
 
+  if (attrs_len < (n_chars + 1))
+    {
+      g_warning ("pango_get_log_attrs(): length of PangoLogAttr array must be at least the number of chars in the text plus one more for the end position");
+      return;
+    }
+  
   lang_map = pango_find_map (language, engine_type_id, render_type_id);
 
   range_start = text;
@@ -1449,7 +1495,8 @@ pango_get_log_attrs (const char    *text,
           pango_break (range_start,
                        pos - range_start,
                        &analysis,
-                       log_attrs + chars_broken);
+                       log_attrs + chars_broken,
+                       attrs_len - chars_broken);
 
           chars_broken += chars_in_range;
 
@@ -1473,6 +1520,7 @@ pango_get_log_attrs (const char    *text,
     pango_break (range_start,
                  end - range_start,
                  &analysis,
-                 log_attrs + chars_broken);
+                 log_attrs + chars_broken,
+                 attrs_len - chars_broken);
 }
 
