@@ -312,7 +312,7 @@ pango_ft2_font_map_for_display (void)
     }
 
   if (!read_font)
-    g_warning ("No fonts found by pangft2. Things will probably not work");
+    g_warning ("No fonts found by pangoft2. Things will probably not work");
   
   pango_ft2_font_map_read_aliases (pango_ft2_global_fontmap);
 
@@ -521,7 +521,7 @@ pango_ft2_font_map_read_alias_file (PangoFT2FontMap *ft2fontmap,
 	  if (!pango_scan_string (&p, tmp_buf))
 	    goto error;
 
-	  face = g_new (PangoFT2Face, 1);
+	  face = g_object_new (PANGO_FT2_TYPE_FACE, NULL);
 	  face->n_fonts = 0;
 	  face->open_args = NULL;
 	  face->face_indices = NULL;
@@ -700,7 +700,7 @@ pango_print_desc (PangoFontDescription *desc)
   PangoStretch stretch = pango_font_description_get_stretch (desc);
   
   g_print ("%s%s%s%s%s",
-	   pango_font_get_family (desc),
+	   pango_font_description_get_family (desc),
 	   (style == PANGO_STYLE_NORMAL ? "" :
 	    (style == PANGO_STYLE_OBLIQUE ? " OBLIQUE" :
 	     (style == PANGO_STYLE_ITALIC ? " ITALIC" : " ???"))),
